]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - sched.h
Rename ->{pre,post}_select methods to ->{pre,post}_monitor.
[paraslash.git] / sched.h
diff --git a/sched.h b/sched.h
index f89b89ffc012551e17febc9de463882eb5c678b6..77dc57488cf2ff103dc59d3b6988b7d1f809bee9 100644 (file)
--- a/sched.h
+++ b/sched.h
@@ -7,15 +7,15 @@
  * Paraslash's scheduler.
  *
  * Designed with KISS in mind. It maintains a list of task structures which is
* extended when a new task is registered. Each task may define a pre_select
  * function which is called from the scheduler main loop before it calls
* select(). Similarly, each task must define a post_select function which is
  * called after the select call.
  *
  * \sa select(2), poll(2).
  */
 struct sched {
/** Initial value (in milliseconds) before any pre_select call. */
        int default_timeout;
        /** The timeout (also in milliseconds) for the next select call. */
        int timeout;
@@ -49,7 +49,7 @@ struct task_info {
         *
         * \sa \ref time.c.
         */
-       void (*pre_select)(struct sched *s, void *context);
+       void (*pre_monitor)(struct sched *s, void *context);
        /**
         * Perform I/O on file descriptors which are ready for I/O.
         *
@@ -60,10 +60,10 @@ struct task_info {
         * If this function returns a negative value, the scheduler unregisters
         * the task.
         */
-       int (*post_select)(struct sched *s, void *context);
+       int (*post_monitor)(struct sched *s, void *context);
        /**
         * This pointer is saved when the task is registered. It is passed to
* ->pre_select() and ->post_select(). Usually this is a pointer to the
         * struct owned by the caller which contains the task pointer.
         */
        void *context;
@@ -7,15 +7,15 @@
  *
  * Designed with KISS in mind. It maintains a list of task structures which is
- * extended when a new task is registered. Each task may define a pre_select
+ * extended when a new task is registered. Each task may define a pre_monitor
  * function which is called from the scheduler main loop before it calls
@@ -7,15 +7,15 @@
  * function which is called from the scheduler main loop before it calls
- * select(). Similarly, each task must define a post_select function which is
+ * select(). Similarly, each task must define a post_monitor function which is
  * called after the select call.
  *
@@ -7,15 +7,15 @@
  */
 struct sched {
-       /** Initial value (in milliseconds) before any pre_select call. */
+       /** Initial value (in milliseconds) before any pre_monitor call. */
        int default_timeout;
        /** The timeout (also in milliseconds) for the next select call. */
@@ -60,10 +60,10 @@ struct task_info {
        /**
         * This pointer is saved when the task is registered. It is passed to
-        * ->pre_select() and ->post_select(). Usually this is a pointer to the
+        * ->pre_monitor() and ->post_monitor(). Usually this is a pointer to the
         * struct owned by the caller which contains the task pointer.
         */